# InterWorx variables
%define pversion 1.0.5
%define bversion 6

# remirepo spec file for php-pecl-mcrypt
#
# Copyright (c) 2017-2022 Remi Collet
# License: CC-BY-SA
# http://creativecommons.org/licenses/by-sa/4.0/
#
# Please, preserve the changelog entries
#

# we don't want -z defs linker flag
%undefine _strict_symbol_defs_build

%{?scl:     %scl_package       php-pecl-mcrypt}

%global with_zts       0%{!?_without_zts:%{?__ztsphp:1}}
%global pecl_name      mcrypt
%global ini_name       30-%{pecl_name}.ini

Summary:      Bindings for the libmcrypt library
Name:         %{?scl_prefix}php-pecl-mcrypt
Version:      1.0.5
Release:      %{bversion}%{?dist}%{!?scl:%{!?nophptag:%(%{__php} -r 'echo ".".PHP_MAJOR_VERSION.".".PHP_MINOR_VERSION;')}}
License:      PHP
URL:          https://pecl.php.net/package/mcrypt

Source0:      https://pecl.php.net/get/%{pecl_name}-%{version}%{?prever}.tgz

BuildRequires: make
BuildRequires: %{?dtsprefix}gcc
BuildRequires: %{?scl_prefix}php-devel >= 7.2
BuildRequires: libmcrypt-devel
BuildRequires: %{?scl_prefix}php-pear

Requires:     %{?scl_prefix}php(zend-abi) = %{php_zend_api}
Requires:     %{?scl_prefix}php(api) = %{php_core_api}
%{?_sclreq:Requires: %{?scl_prefix}runtime%{?_sclreq}%{?_isa}}

Provides:     %{?scl_prefix}php-pecl(%{pecl_name}) = %{version}
Provides:     %{?scl_prefix}php-pecl(%{pecl_name})%{?_isa} = %{version}
# Set epoch so provides is > 0:7.1
Obsoletes:    %{?scl_prefix}php-%{pecl_name}         < 7.2
Provides:     %{?scl_prefix}php-%{pecl_name}         = 1:%{version}-%{release}
Provides:     %{?scl_prefix}php-%{pecl_name}%{?_isa} = 1:%{version}-%{release}


%if "%{?packager}" == "Remi Collet" && 0%{!?scl:1} && 0%{?rhel}
Obsoletes:     php54u-%{pecl_name}      <  7.2
Obsoletes:     php54w-%{pecl_name}      <  7.2
Obsoletes:     php55u-%{pecl_name}      <  7.2
Obsoletes:     php55w-%{pecl_name}      <  7.2
Obsoletes:     php56u-%{pecl_name}      <  7.2
Obsoletes:     php56w-%{pecl_name}      <  7.2
Obsoletes:     php70u-%{pecl_name}      <  7.2
Obsoletes:     php70w-%{pecl_name}      <  7.2
Obsoletes:     php71u-%{pecl_name}      <  7.2
Obsoletes:     php71w-%{pecl_name}      <  7.2
Obsoletes:     php72u-pecl-%{pecl_name} <= %{version}
Obsoletes:     php72w-pecl-%{pecl_name} <= %{version}
%if "%{php_version}" > "7.3"
Obsoletes:      php73-pecl-%{pecl_name} <= %{version}
Obsoletes:     php73w-pecl-%{pecl_name} <= %{version}
%endif
%if "%{php_version}" > "7.4"
Obsoletes:      php74-pecl-%{pecl_name} <= %{version}
%endif
%if "%{php_version}" > "8.0"
Obsoletes:      php80-pecl-%{pecl_name} <= %{version}
%endif
%if "%{php_version}" > "8.1"
Obsoletes:      php81-pecl-%{pecl_name} <= %{version}
%endif
%endif


%description
Provides bindings for the unmaintained libmcrypt.

Package built for PHP %(%{__php} -r 'echo PHP_MAJOR_VERSION.".".PHP_MINOR_VERSION;')%{?scl: as Software Collection (%{scl} by %{scl_vendor})}.


%prep 
%setup -c -q
mv %{pecl_name}-%{version}%{?prever} NTS

# Don't install/register tests
sed -e 's/role="test"/role="src"/' \
    %{?_licensedir:-e '/LICENSE/s/role="doc"/role="src"/' } \
    -i package.xml

cd NTS
# Sanity check, really often broken
extver=$(sed -n '/#define PHP_MCRYPT_VERSION/{s/.* "//;s/".*$//;p}' php_mcrypt.h)
if test "x${extver}" != "x%{version}%{?prever}"; then
   : Error: Upstream extension version is ${extver}, expecting %{version}%{?prever}.
   exit 1
fi

cd ..
: Create the configuration file
cat >%{ini_name} << 'EOF'
; Enable %{pecl_name} extension module
extension=%{pecl_name}
EOF

%if %{with_zts}
: Duplicate sources tree for ZTS build
cp -pr NTS ZTS
%endif


%build
%{?dtsenable}

cd NTS
%{_bindir}/phpize
%configure \
  --with-mcrypt \
  --with-php-config=%{_bindir}/php-config

make %{?_smp_mflags}

%if %{with_zts}
cd ../ZTS
%{_bindir}/zts-phpize
%configure \
  --with-mcrypt \
  --with-php-config=%{_bindir}/zts-php-config

make %{?_smp_mflags}
%endif


%install
%{?dtsenable}

make -C NTS install INSTALL_ROOT=%{buildroot}
install -D -m 644 %{ini_name} %{buildroot}%{php_inidir}/%{ini_name}

# Install XML package description
install -D -m 644 package.xml %{buildroot}%{pecl_xmldir}/%{name}.xml

%if %{with_zts}
make -C ZTS install INSTALL_ROOT=%{buildroot}
install -D -m 644 %{ini_name} %{buildroot}%{php_ztsinidir}/%{ini_name}
%endif

# Documentation
cd NTS
for i in $(grep 'role="doc"' ../package.xml | sed -e 's/^.*name="//;s/".*$//')
do install -Dpm 644 $i %{buildroot}%{pecl_docdir}/%{pecl_name}/$i
done


%check
# Warning: Use of undefined constant MCRYPT_CBC - assumed 'MCRYPT_CBC'
rm ?TS/tests/bug8040.phpt

cd NTS
: minimal load test of NTS extension
%{_bindir}/php --no-php-ini \
    --define extension_dir=modules \
    --define extension=%{pecl_name} \
    --modules | grep %{pecl_name}

%if "%{php_version}" > "7.4"
OPT="%{?_smp_mflags} -q --show-diff"
%else
OPT="-q --show-diff"
%endif

: upstream test suite for NTS extension
TEST_PHP_EXECUTABLE=%{__php} \
TEST_PHP_ARGS="-n -d extension=%{buildroot}%{php_extdir}/%{pecl_name}.so" \
%{__php} -n run-tests.php $OPT

%if %{with_zts}
cd ../ZTS
: minimal load test of ZTS extension
%{__ztsphp} --no-php-ini \
    --define extension_dir=modules \
    --define extension=%{pecl_name} \
    --modules | grep %{pecl_name}

: upstream test suite for ZTS extension
TEST_PHP_EXECUTABLE=%{__ztsphp} \
TEST_PHP_ARGS="-n -d extension=%{buildroot}%{php_ztsextdir}/%{pecl_name}.so" \
%{__ztsphp} -n run-tests.php $OPT
%endif


%if 0%{?fedora} < 24 && 0%{?rhel} < 8
# when pear installed alone, after us
%triggerin -- %{?scl_prefix}php-pear
if [ -x %{__pecl} ] ; then
    %{pecl_install} %{pecl_xmldir}/%{name}.xml >/dev/null || :
fi

# posttrans as pear can be installed after us
%posttrans
if [ -x %{__pecl} ] ; then
    %{pecl_install} %{pecl_xmldir}/%{name}.xml >/dev/null || :
fi

%postun
if [ $1 -eq 0 -a -x %{__pecl} ] ; then
    %{pecl_uninstall} %{pecl_name} >/dev/null || :
fi
%endif


%files
%{?_licensedir:%license NTS/LICENSE}
%{!?_licensedir:%doc %{pecl_docdir}/%{pecl_name}}
%{pecl_xmldir}/%{name}.xml

%config(noreplace) %{php_inidir}/%{ini_name}
%{php_extdir}/%{pecl_name}.so

%if %{with_zts}
%config(noreplace) %{php_ztsinidir}/%{ini_name}
%{php_ztsextdir}/%{pecl_name}.so
%endif


%changelog
* Tue Sep 20 2022 InterWorx Build System <support@interworx.com> - 1.0.5-1
- Automated rebasing of iworx version onto upstream 1.0.5-1

* Mon May 23 2022 Remi Collet <remi@remirepo.net> - 1.0.5-1
- update to 1.0.5

* Wed Sep 01 2021 Remi Collet <remi@remirepo.net> - 1.0.4-5
- rebuild for 8.1.0RC1

* Wed Jun  9 2021 Remi Collet <remi@remirepo.net> - 1.0.4-4
- add upstream patch for test suite with PHP 8.1
- run tests in parallel (7.4+)

* Fri Apr 30 2021 Remi Collet <remi@remirepo.net> - 1.0.4-3
- F34 rebuild for https://github.com/remicollet/remirepo/issues/174

* Wed Dec  2 2020 Remi Collet <remi@remirepo.net> - 1.0.4-1
- update to 1.0.4

* Fri Nov 27 2020 Remi Collet <remi@remirepo.net> - 1.0.3-4
- add upstream patches for PHP 8

* Wed Sep 18 2019 Remi Collet <remi@remirepo.net> - 1.0.3-1
- update to 1.0.3 (no change)

* Tue Sep 03 2019 Remi Collet <remi@remirepo.net> - 1.0.2-4
- rebuild for 7.4.0RC1

* Tue Jul 23 2019 Remi Collet <remi@remirepo.net> - 1.0.2-3
- rebuild for 7.4.0beta1

* Fri Feb  8 2019 Remi Collet <remi@remirepo.net> - 1.0.2-2
- fix upgrade patch from other 3rd party repo

* Fri Jan 11 2019 Remi Collet <remi@remirepo.net> - 1.0.2-1
- update to 1.0.2

* Thu Aug 16 2018 Remi Collet <remi@remirepo.net> - 1.0.1-8
- rebuild for 7.3.0beta2 new ABI

* Wed Jul 18 2018 Remi Collet <remi@remirepo.net> - 1.0.1-7
- rebuild for 7.3.0alpha4 new ABI

* Mon May 28 2018 Remi Collet <remi@remirepo.net> - 1.0.1-6
- manage update from other 3rd party repo

* Wed Jan 10 2018 Remi Collet <remi@remirepo.net> - 1.0.1-5
- use run-tests.php instead of make test

* Tue Jul 18 2017 Remi Collet <remi@remirepo.net> - 1.0.1-4
- rebuild for PHP 7.2.0beta1 new API

* Fri Jul  7 2017 Remi Collet <remi@remirepo.net> - 1.0.1-3
- drop .so extension for configuration file

* Wed Jun 21 2017 Remi Collet <remi@remirepo.net> - 1.0.1-2
- rebuild for 7.2.0alpha2

* Wed Apr 12 2017 Remi Collet <remi@remirepo.net> - 1.0.1-1
- New spec for version 1.0.1 (PHP 7.2)
